summaryrefslogtreecommitdiffstats
path: root/kbackgammon/kbgstatus.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbackgammon/kbgstatus.h')
-rw-r--r--kbackgammon/kbgstatus.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kbackgammon/kbgstatus.h b/kbackgammon/kbgstatus.h
index 5543e1ca..afcc2f6a 100644
--- a/kbackgammon/kbgstatus.h
+++ b/kbackgammon/kbgstatus.h
@@ -27,7 +27,7 @@
#include <config.h>
#endif
-#include <qobject.h>
+#include <tqobject.h>
/**
@@ -70,7 +70,7 @@ class KBgStatus : public QObject
/**
* Constructor from a FIBS rawboard string
*/
- KBgStatus(const QString &rawboard);
+ KBgStatus(const TQString &rawboard);
/**
* Copy constructor
@@ -156,10 +156,10 @@ class KBgStatus : public QObject
/*
* Return the name of player w. If w is out of bounds or if
* the player names have not been set, QString::null is
* returned.
*/
- QString player(const int &w = US) const;
+ TQString player(const int &w = US) const;
/*
* Return the length of the game. Negative values should be used to
@@ -260,7 +260,7 @@ class KBgStatus : public QObject
* Set the name of player w to name. If w is out of bound,
* nothing is done.
*/
- void setPlayer(const int &w, const QString &name);
+ void setPlayer(const int &w, const TQString &name);
/*
* Set the length of the game. Negative values should be used to
@@ -298,7 +298,7 @@ class KBgStatus : public QObject
/*
* Private variables with self-expalanatory names.
*/
- QString player_[2];
+ TQString player_[2];
int board_[26], home_[2], bar_[2], dice_[2][2], points_[2];
int color_, direction_, cube_, length_, turn_;
@@ -156,10 +156,10 @@ class KBgStatus : public QObject
/*
* Return the name of player w. If w is out of bounds or if
- * the player names have not been set, QString::null is
+ * the player names have not been set, TQString::null is
* returned.
*/